package com.infoepoch.pms.agent.platform.chatbot.domain.irepository;

import com.infoepoch.pms.agent.common.utils.AbstractCriteria;

/**
 * @author jiangyz
 * @date 2026/4/18 12:57
 * 聊天机器人定义查询条件类
 */
public class ChatbotCriteria extends AbstractCriteria {

    //region 聊天机器人名称，系统内唯一
    public boolean byName() {
        return this.andMap.containsKey("Name");
    }

    private String name;

    public String getName() {
        if (byName())
            return name;
        return null;
    }

    public void setName(String value) {
        this.name = value;
        this.andMap.put("Name", value);
    }
    //endregion

    //region 绑定的模型配置主键，为空则使用系统默认模型
    public boolean byModelConfigId() {
        return this.andMap.containsKey("ModelConfigId");
    }

    private String modelConfigId;

    public String getModelConfigId() {
        if (byModelConfigId())
            return modelConfigId;
        return null;
    }

    public void setModelConfigId(String value) {
        this.modelConfigId = value;
        this.andMap.put("ModelConfigId", value);
    }
    //endregion

    //region 聊天机器人是否启用
    public boolean byEnabled() {
        return this.andMap.containsKey("Enabled");
    }

    private Boolean enabled;

    public Boolean getEnabled() {
        if (byEnabled())
            return enabled;
        return null;
    }

    public void setEnabled(Boolean value) {
        this.enabled = value;
        this.andMap.put("Enabled", value);
    }
    //endregion

}